package com.ruoyi.bst.ad.service;

import java.util.List;
import com.ruoyi.bst.ad.domain.Ad;
import com.ruoyi.bst.ad.domain.AdVO;
import com.ruoyi.bst.ad.domain.AdQuery;
import com.ruoyi.bst.ad.domain.AdVerifyDTO;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.fault.domain.Fault;
import com.ruoyi.bst.fault.domain.FaultVO;
import com.ruoyi.bst.fault.domain.FaultVerifyDTO;

/**
 * 广告Service接口
 *
 * @author ruoyi
 * @date 2025-04-01
 */
public interface AdService
{
    /**
     * 查询广告
     *
     * @param adId 广告主键
     * @return 广告
     */
    public AdVO selectAdByAdId(Long adId);

    /**
     * 查询广告列表
     *
     * @param ad 广告
     * @return 广告集合
     */
    public List<AdVO> selectAdList(AdQuery ad);

    /**
     * 新增广告
     *
     * @param ad 广告
     * @return 结果
     */
    public int insertAd(Ad ad);

    /**
     * 修改广告
     *
     * @param ad 广告
     * @return 结果
     */
    public int updateAd(Ad ad);

    /**
     * 批量删除广告
     *
     * @param adIds 需要删除的广告主键集合
     * @return 结果
     */
    public int deleteAdByAdIds(List<Long> adIds);

    /**
     * 删除广告信息
     *
     * @param adId 广告主键
     * @return 结果
     */
    public int deleteAdByAdId(Long adId);

    AdVO selectOne(AdQuery adQuery);



    public int logicalDel(List<Long> adIds);

    public int verify(AdVerifyDTO dto);

    /**
     * 启用
     */
    public int enable(Long adId);

    /**
     * 禁用
     */
    public int disable(Long adId);

}
